@@ -85,7 +85,8 @@ def plot_robot(
     transformations=None, 
     visible_collision=False, 
     visible_text=True,
-    visible_scatter=True):
+    visible_scatter=True,
+    visible_basis=True):
 
     """
     Plot robot
@@ -94,7 +95,9 @@ def plot_robot(
         transformations = robot.init_transformations
 
     name = robot.robot_name
-    plot_basis(robot, ax)
+
+    if visible_basis:
+        plot_basis(robot, ax)
     
     links = []
     nodes = []
